cmd

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 12, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var RootCmd = &cobra.Command{
	Use:     "cclint",
	Short:   "A linter for Claude Code configurations",
	Version: version.Short(),
	Long: `cclint analyzes Claude Code configurations and related files
to identify issues, suggest improvements, and ensure best practices.

It builds a reference tree of your agent configurations, analyzes
documentation quality, and checks for common problems like broken
references, circular dependencies, and unclear instructions.`,
	PersistentPreRun: func(cmd *cobra.Command, args []string) {

		globalUI = ui.New(os.Stdout, os.Stderr, format)
	},
}

Functions

func GetUI

func GetUI() *ui.UI

GetUI returns the global UI instance for use by subcommands

Types

This section is empty.

Jump to